@@ -64,7 +64,7 @@ class Exceptions:
 
 class QLDBClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html)
     """
 
@@ -73,15 +73,15 @@ class QLDBClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#can_paginate)
         """
 
     def cancel_journal_kinesis_stream(
-        self, LedgerName: str, StreamId: str
+        self, *, LedgerName: str, StreamId: str
     ) -> CancelJournalKinesisStreamResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.cancel_journal_kinesis_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#cancel_journal_kinesis_stream)
         """
 
@@ -94,35 +94,35 @@ class QLDBClient:
         DeletionProtection: bool = None
     ) -> CreateLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.create_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.create_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#create_ledger)
         """
 
-    def delete_ledger(self, Name: str) -> None:
+    def delete_ledger(self, *, Name: str) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.delete_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.delete_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#delete_ledger)
         """
 
     def describe_journal_kinesis_stream(
-        self, LedgerName: str, StreamId: str
+        self, *, LedgerName: str, StreamId: str
     ) -> DescribeJournalKinesisStreamResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.describe_journal_kinesis_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_journal_kinesis_stream)
         """
 
     def describe_journal_s3_export(
-        self, Name: str, ExportId: str
+        self, *, Name: str, ExportId: str
     ) -> DescribeJournalS3ExportResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.describe_journal_s3_export)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_journal_s3_export)
         """
 
-    def describe_ledger(self, Name: str) -> DescribeLedgerResponseTypeDef:
+    def describe_ledger(self, *, Name: str) -> DescribeLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.describe_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.describe_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#describe_ledger)
         """
 
@@ -136,7 +136,7 @@ class QLDBClient:
         RoleArn: str
     ) -> ExportJournalToS3ResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.export_journal_to_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#export_journal_to_s3)
         """
 
@@ -148,7 +148,7 @@ class QLDBClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#generate_presigned_url)
         """
 
@@ -160,13 +160,13 @@ class QLDBClient:
         DigestTipAddress: "ValueHolderTypeDef" = None
     ) -> GetBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.get_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.get_block)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_block)
         """
 
-    def get_digest(self, Name: str) -> GetDigestResponseTypeDef:
+    def get_digest(self, *, Name: str) -> GetDigestResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.get_digest)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.get_digest)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_digest)
         """
 
@@ -179,7 +179,7 @@ class QLDBClient:
         DigestTipAddress: "ValueHolderTypeDef" = None
     ) -> GetRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.get_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.get_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#get_revision)
         """
 
@@ -187,15 +187,15 @@ class QLDBClient:
         self, *, LedgerName: str, MaxResults: int = None, NextToken: str = None
     ) -> ListJournalKinesisStreamsForLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.list_journal_kinesis_streams_for_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_kinesis_streams_for_ledger)
         """
 
     def list_journal_s3_exports(
-        self, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListJournalS3ExportsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_s3_exports)
         """
 
@@ -203,21 +203,21 @@ class QLDBClient:
         self, *, Name: str, MaxResults: int = None, NextToken: str = None
     ) -> ListJournalS3ExportsForLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.list_journal_s3_exports_for_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_journal_s3_exports_for_ledger)
         """
 
     def list_ledgers(
-        self, MaxResults: int = None, NextToken: str = None
+        self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListLedgersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.list_ledgers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.list_ledgers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_ledgers)
         """
 
-    def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#list_tags_for_resource)
         """
 
@@ -233,34 +233,34 @@ class QLDBClient:
         ExclusiveEndTime: datetime = None
     ) -> StreamJournalToKinesisResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.stream_journal_to_kinesis)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#stream_journal_to_kinesis)
         """
 
-    def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#tag_resource)
         """
 
-    def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#untag_resource)
         """
 
     def update_ledger(
-        self, Name: str, DeletionProtection: bool = None
+        self, *, Name: str, DeletionProtection: bool = None
     ) -> UpdateLedgerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.update_ledger)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.update_ledger)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#update_ledger)
         """
 
     def update_ledger_permissions_mode(
-        self, Name: str, PermissionsMode: PermissionsModeType
+        self, *, Name: str, PermissionsMode: PermissionsModeType
     ) -> UpdateLedgerPermissionsModeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/qldb.html#QLDB.Client.update_ledger_permissions_mode)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.94/reference/services/qldb.html#QLDB.Client.update_ledger_permissions_mode)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_qldb/client.html#update_ledger_permissions_mode)
         """
